==> lapisworks-1.5.6.8-sources.jar: com/luxof/lapisworks/blocks/Mind.java <==
package com.luxof.lapisworks.blocks;

import com.luxof.lapisworks.blocks.entities.MindEntity;
import com.luxof.lapisworks.init.ModBlocks;
import net.minecraft.class_1937;
import net.minecraft.class_2237;
import net.minecraft.class_2248;
import net.minecraft.class_2338;
import net.minecraft.class_2464;
import net.minecraft.class_2498;
import net.minecraft.class_2586;
import net.minecraft.class_2591;
import net.minecraft.class_2680;
import net.minecraft.class_2689;
import net.minecraft.class_2758;
import net.minecraft.class_4970;
import net.minecraft.class_5558;

public class Mind extends class_2237 {
    public Mind() {
        // strong as deepslate
        super(class_4970.class_2251.method_9637().method_9626(class_2498.field_29035).method_9618());
    }

    // i REFUSE to use BERs (scawy)
    public static final class_2758 FILLED = class_2758.method_11867("filled", 0, 14);

    @Override
    public class_2586 method_10123(class_2338 pos, class_2680 state) {
        return new MindEntity(pos, state);
    }

    @Override
    public class_2464 method_9604(class_2680 state) {
        return class_2464.field_11458;
    }

    @Override
    public <T extends class_2586> class_5558<T> method_31645(
        class_1937 world,
        class_2680 state,
        class_2591<T> type
    ) {
        // checkType() makes me required to do an "unsafe cast" for whatever reason
        if (type == ModBlocks.MIND_ENTITY_TYPE) { return MindEntity::tick; }
        else { return null; }
    }

    @Override
    protected void method_9515(class_2689.class_2690<class_2248, class_2680> builder) {
        builder.method_11667(FILLED);
    }
}

==> lapisworks-1.5.7-sources.jar: com/luxof/lapisworks/blocks/Mind.java <==
package com.luxof.lapisworks.blocks;

import com.luxof.lapisworks.blocks.entities.MindEntity;
import com.luxof.lapisworks.init.ModBlocks;
import net.minecraft.class_1937;
import net.minecraft.class_2237;
import net.minecraft.class_2248;
import net.minecraft.class_2338;
import net.minecraft.class_2464;
import net.minecraft.class_2498;
import net.minecraft.class_2586;
import net.minecraft.class_2591;
import net.minecraft.class_2680;
import net.minecraft.class_2689;
import net.minecraft.class_2758;
import net.minecraft.class_5558;

public class Mind extends class_2237 {
    public Mind() {
        // strong as deepslate
        super(
            class_2251.method_9637().method_9626(class_2498.field_29035).method_9618().method_22488()
        );
    }

    // i REFUSE to use BERs (scawy)
    public static final class_2758 FILLED = class_2758.method_11867("filled", 0, 14);

    @Override
    public class_2586 method_10123(class_2338 pos, class_2680 state) {
        return new MindEntity(pos, state);
    }

    @Override
    public class_2464 method_9604(class_2680 state) {
        return class_2464.field_11458;
    }

    @Override
    public <T extends class_2586> class_5558<T> method_31645(
        class_1937 world,
        class_2680 state,
        class_2591<T> type
    ) {
        // checkType() makes me required to do an "unsafe cast" for whatever reason
        if (type == ModBlocks.MIND_ENTITY_TYPE) { return MindEntity::tick; }
        else { return null; }
    }

    @Override
    protected void method_9515(class_2689.class_2690<class_2248, class_2680> builder) {
        builder.method_11667(FILLED);
    }
}
